/**
 * api
 * GIC卡券
 */
import getFetch from './get-fetch.js';
import config, { marketPrefix } from '@/config';


// 卡券相关接口
let card = {
  cardList: '/coupon-gic/gic-coupon-page', // 卡券列表
  addCard: {
    // 新增卡券
    url: '/coupon-gic/save-gic-coupon',
    method: 'post',
    useFormData: true,
  },
  updateCard: {
    // 修改卡券
    url: '/coupon-gic/update-gic-coupon',
    method: 'post',
    useFormData: true,
  },
  copyCard: '/coupon-gic/copy-gic-coupon',  // 拷贝卡券
  cardInfo: '/coupon-gic/get-gic-coupon-detail', // 卡券详情
  updateCardStock: '/coupon-gic/update-gic-coupon-stock', // 修改库存
  deleteCard: '/coupon-gic/delete-gic-coupon', // 删除卡券
  giveLogList: '/coupon-gic/gic-coupon-give-log-page', // 卡券转赠记录
  groupSendAdd: {
    // 新建投放
    url: '/coupon-gic/coupon-puton',
    method: 'post',
    useFormData: true,
  },
  groupSendList: '/coupon-gic/coupon-plan-page', // 卡券投放列表
  groupSendInfo: '/coupon-gic/coupon-puton-detail', // 卡券投放详情
  groupSendInfoLog: '/coupon-gic/coupon-puton-log-page', // 卡券投放记录
  couponPutonFailLogList: '/coupon-gic/coupon-puton-fail-log-page', // 卡券投放失败详情
  stopGroupSend: '/coupon-gic/stop-coupon-puton-timed-task', // 禁用投放
  codeErrorList: '/gic-coupon-code-error-page', // 查询导入券券码错误列表
  gicCardListByName: '/coupon-gic/list-coupon-names', // 根据name模糊查询卡券列表
  checkDemoCode: {
    // 根据demo code
    url: '/coupon-gic/check-demo-code',
    alertError: false
  },
  cardDestoryList: '/destroy-plugin/page-destroy-plan', // 卡券销毁分页列表
  exportDestroyLogExcel: {
    // 卡券销毁记录导出
    url: '/export-destroy-log-excel',
    method: 'post',
    export: true,
    headers: { 'Content-Type': 'application/json' }
  },
  saveCoupDestoryPlan: {
    // 保存卡券销毁
    url: '/destroy-plugin/save-destroy-plan',
    method: 'post',
    useFormData: true,
  },
  couponlogList: '/coupon-gic/coupon-log-page', // 会员领取记录
  exportCoupReceivedLog: {
    // 导出会员领取记录
    url: '/export-coup-received-log-excel',
    method: 'post',
    export: true,
    headers: { 'Content-Type': 'application/json' }
  },
  exportCoupGiveLog: {
    // 导出转赠记录
    url: '/export-gic-coupon-give-log-excel',
    method: 'post',
    export: true,
    headers: { 'Content-Type': 'application/json' }
  },
  exportCouponPutonLog: {
    // 导出卡券投放详情
    url: '/export-coupon-puton-log-excel',
    method: 'post',
    export: true,
    headers: { 'Content-Type': 'application/json' }
  },
  couponConsumeOrder: '/coupon-gic/coupon-consume-order', // 核销 - 订单信息
  couponConsume: '/coupon-gic/coupon-consume', // 核销 - 核销
  couponDestroy: '/coupon-gic/coupon-destroy', // 销毁
};

// 卡券同步库存
let syncStock = {
  getCouponStockInfo: '/coupon-gic/get-coupon-stock-info', // 获取卡券同步信息
  returnStock: '/coupon-gic/return-welfare-coupon', // 卡券返还
  syncStock: '/coupon-gic/syn-welfare-coupon', // 卡券同步库存
  getWelfareStock: '/coupon-gic/get-welfare-stock', // 获取福利库存
  getSyncWelfareList: '/coupon-gic/syn-welfare-coupon-page', // 卡券同步记录列表
};

// 卡券展架
let shelf = {
  saveShelf: {
    // 保存（新增、更新）
    url: '/coupon-gic/save-shelf',
    method: 'post',
    useFormData: true,
  },
  getShelfList: '/coupon-gic/list-shelf-page', // 获取展架列表
  getShelfInfo: '/coupon-gic/shelf-detail', // 获取展架详情
  delShelf: '/coupon-gic/delete-shelf', // 删除某个展架
  getShelfCoupon: '/coupon-gic/list-shelf-coupon', // 获取展架使用的卡券
};

// 卡券包
let packages = {
  savePackages: {
    // 新增、编辑卡券包  /coupon-package/save-package  /coupon-package/edit-package
    url: '/coupon-package/{type}-package', // edit add
    method: 'post',
    useFormData: true,
    rest: true
  },
  pageCouponPackage: '/coupon-package/page-coupon-package', // 获取卡券包列表
  pagePackageLog: '/coupon-package/page-package-log', // 卡券包领取记录
  packageCouponReceiveLog: '/coupon-package/package-coupon-receive-log', // 卡券领取记录详情
  getPackageDetail: '/coupon-package/get-package-detail', // 获取卡券包详情
  deletePackage: '/coupon-package/delete-package', // 删除某个卡券包
  optPackageStock: '/coupon-package/opt-package-stock', // 调整卡券包库存
};
// 其他接口
let other = {
  auditList: '/coupon/audit-log-page', // 审核记录
  // 子应用相关配置↓
  auditSettingInfo: '/coupon/audit-setting-info', // 子应用审核配置
  auditSettingSave: {
    // 子应用保存更新
    url: '/coupon/audit-setting',
    method: 'post',
    useFormData: true
  },
  getCouponSendLogList: '/coupon-gic/coupon-send-log', // 卡券发放成功记录
  getMarketAppcodes: '/market/market-appcodes', // 来源模块codeList
  getCouponSendFailLogList: '/coupon-gic/coupon-send-fail-log', // 卡券发放失败记录
};

card = getFetch(card, marketPrefix);
syncStock = getFetch(syncStock, marketPrefix);
shelf = getFetch(shelf, marketPrefix);
packages = getFetch(packages, marketPrefix);
other = getFetch(other, marketPrefix);

export default { ...card, ...other, ...syncStock, ...shelf, ...packages };


export const downloadCouponCSV = config.api + marketPrefix + '/download-code-csv-template'; // 下载导入GIC券号csv示例文件
export const importCode = config.api + marketPrefix + '/import-gic-custom-code'; // 导入券码
export const importDestoryCode = marketPrefix + '/destroy-plugin/import-destroy-code'; // 上传销毁code列表
export const downloadDestroyCodeTemplate = config.api + marketPrefix + '/destroy-plugin/download-destroy-code-template'; // 下载销毁模板示例

